@@ -2,6 +2,7 @@
 Airflow representation classes
 """
 import datetime
+import os
 from time import sleep
 from typing import Dict, List, NamedTuple, Optional
 
@@ -29,7 +30,7 @@ class MissingDAGException(BaseException):
 class AirflowClient:
     MAX_RETRIES = 10
     RETRY_INTERVAL = 10
-    VERIFY = False
+    VERIFY = os.environ.get("AIRFLOW__CLIENT__SSL_VERIFY", "True") == "True"
     """
     Client of Airflow. Supports both low level functionalities of Airflow and some high
      level aggregates on top of them.
@@ -37,14 +38,14 @@ class AirflowClient:
 
     def __init__(
         self,
-        rest_api_url: str,
+        airflow_url: str,
         max_retries: int = MAX_RETRIES,
         retry_interval: int = RETRY_INTERVAL,
     ):
         """
         :param rest_api_url: full url to service rest API
         """
-        self.rest_api_url = rest_api_url
+        self.rest_api_url = f"{airflow_url}/api/v1"
         self.max_retries = max_retries
         self.retry_interval = retry_interval
 
@@ -126,10 +127,19 @@ class AirflowClient:
         return res.json()["dag_run_id"]
 
     @staticmethod
-    def _check_state(response):
+    def _check_task_instances_state(response) -> Optional[str]:
+        if response.status_code != 200:
+            return None
+        instances = response.json()["task_instances"]
+        failed_instances = [i for i in instances if i["state"] == "failed"]
+        return "failed" if len(failed_instances) > 0 else None
+
+    @staticmethod
+    def _check_dag_run_state(response) -> Optional[str]:
         if response.status_code != 200:
             return "unknown"
         state = response.json()["state"]
+
         return state if state != "running" else None
 
     def _wait_for_dag_run_completion(
@@ -146,9 +156,18 @@ class AirflowClient:
                 headers={"Content-Type": "application/json"},
                 verify=AirflowClient.VERIFY,
             )
-            last_state = AirflowClient._check_state(res)
-            if last_state:
-                break
+            last_state = AirflowClient._check_dag_run_state(res)
+            if last_state == "success":
+                res = session.get(
+                    f"{self.rest_api_url}/dags/{dag_id}/dagRuns/{dag_run_id}/"
+                    f"taskInstances"
+                )
+                return (
+                    AirflowClient._check_task_instances_state(res) or "success"
+                )
+
+            if last_state is not None:
+                return last_state
 
             sleep(self.retry_interval)
         return last_state
@@ -170,3 +189,38 @@ class AirflowClient:
             )
         else:
             return "unknown"
+
+    def list_dags(self, tag_prefix: Optional[str] = None) -> List[DAGModel]:
+        """
+        List dags, optionally filter by tag prefix.
+        :param tag_prefix: if specify, filter
+        :return: DAGModel
+        :raises: RuntimeError on HTTP error
+        """
+        session = AirflowClient.create_http_session()
+        res = session.get(
+            f"{self.rest_api_url}/dags?limit=1000", verify=AirflowClient.VERIFY
+        )
+
+        if res.status_code != 200:
+            raise RuntimeError(res.json().get("title"))
+
+        dags = res.json()["dags"]
+
+        def contains_prefix(tags_list: List[Dict[str, str]]) -> bool:
+            return (
+                len(
+                    [
+                        tag
+                        for tag in tags_list
+                        if tag["name"].startswith(tag_prefix)
+                    ]
+                )
+                > 0
+            )
+
+        return [
+            DAGModel(dag_id=dag["dag_id"], tags=dag["tags"])
+            for dag in dags
+            if contains_prefix(dag.get("tags", []))
+        ]
